<?php global $cyarb_opt;
/**
 * Functions which enhance the opt by hooking into WordPress
 *
 * @package cyarb
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function cyarb_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}
	
	return $classes;
}
add_filter( 'body_class', 'cyarb_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function cyarb_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'cyarb_pingback_header' );


// Return Space
if ( ! function_exists( 'cyarb_excerpt_more_ret_space' ) ) {
	function cyarb_excerpt_more_ret_space($more) {
		return '';
	}
}
add_filter('excerpt_more', 'cyarb_excerpt_more_ret_space');

// Filter the categories archive widget to add a span around post count
if ( ! function_exists( 'cyarb_cat_count_span' ) ) {
	function cyarb_cat_count_span( $links ) {
		$links = str_replace( '</a> (', '</a><span class="post-count">(', $links );
		$links = str_replace( ')', ')</span>', $links );
		return $links;
	}
}
add_filter( 'wp_list_categories', 'cyarb_cat_count_span' );

// Filter the archives widget to add a span around post count
if ( ! function_exists( 'cyarb_archive_count_span' ) ) {
	function cyarb_archive_count_span( $links ) {
		$links = str_replace( '</a>&nbsp;(', '</a><span class="post-count">(', $links );
		$links = str_replace( ')', ')</span>', $links );
		return $links;
	}
}
add_filter( 'get_archives_link', 'cyarb_archive_count_span' );

// For Page.php
if ( ! function_exists( 'cyarb_is_elementor' ) ) {
	function cyarb_is_elementor(){
		if ( function_exists( 'elementor_load_plugin_textdomain' ) ):
			global $post;
			return \Elementor\Plugin::$instance->documents->get( $post->ID )->is_built_with_elementor();
		endif;
	}
}
/**
 * Menu Registration
*/
if ( ! function_exists( 'cyarb_register_primary_menus' ) ) :
	function cyarb_register_primary_menus(){
		register_nav_menus(
			array(
				'primary' 			=> esc_html__('Primary Menu', 'cyarb'),
			)
		);
	}
endif;
add_action('init', 'cyarb_register_primary_menus');

// Remove auto p from Contact Form 7 shortcode output
if ( ! function_exists( 'cyarb_remove_extra_p_from_cf7' ) ) {
	function cyarb_remove_extra_p_from_cf7() {
		return false;
	}
}
add_filter('wpcf7_autop_or_not', 'cyarb_remove_extra_p_from_cf7');

/**
  * Cyarb Nav
*/
if ( ! function_exists( 'cyarb_nav_area' ) ) :
	function cyarb_nav_area() {
		if ( class_exists('ACF') && get_field('choose_header_style') == 2 ) {
			get_template_part('template-parts/header/style','1-2');
		} elseif ( class_exists('ACF') && get_field('choose_header_style') == 3 ) {
			get_template_part('template-parts/header/style','3');
		} elseif ( class_exists('ACF') && get_field('choose_header_style') == 4 ) {
			get_template_part('template-parts/header/style','4');
		} else {
			get_template_part('template-parts/header/style','1-2');
		}
	}
endif;

/**
 * Cyarb RTL
*/
if( ! function_exists( 'cyarb_rtl' ) ):
	function cyarb_rtl() {
		global $cyarb_opt;

		if(	isset( $cyarb_opt['cyarb_enable_rtl'])  ):
			$cyarb_rtl_opt = $cyarb_opt['cyarb_enable_rtl'];
		else:
			$cyarb_rtl_opt = 'disable';
		endif;

		if ( isset( $_GET['rtl'] ) ) {
			$cyarb_rtl_opt = $_GET['rtl'];
		}

		if ( $cyarb_rtl_opt == 'enable' ) :
			$cyarb_rtl = true;
		else:
			$cyarb_rtl = false;
		endif;

		return $cyarb_rtl;
	}
endif;